@@ -371,7 +371,7 @@ def _serialize_single(
     return output
 
 
-def decode_varint(buffer: bytes, pos: int, signed: bool = False) -> Tuple[int, int]:
+def decode_varint(buffer: bytes, pos: int) -> Tuple[int, int]:
     """
     Decode a single varint value from a byte buffer. Returns the value and the
     new position in the buffer.
@@ -383,7 +383,7 @@ def decode_varint(buffer: bytes, pos: int, signed: bool = False) -> Tuple[int, i
         result |= (b & 0x7F) << shift
         pos += 1
         if not (b & 0x80):
-            return (result, pos)
+            return result, pos
         shift += 7
         if shift >= 64:
             raise ValueError("Too many bytes when decoding varint.")
@@ -854,8 +854,8 @@ class Message(ABC):
         :param http_code:
         :return:
         """
-        assert self.status_code == http_code, f'[校验失败,http_code 实际值:{self.status_code} == 预期值：{http_code}]'
-        logger.info(f'[校验成功,http_code 实际值:{self.status_code} == 预期值：{http_code}]')
+        assert self.status_code == http_code, f'[校验失败,http_code 实际值:{self.status_code} == 预期值:{http_code}]'
+        logger.info(f'[校验成功,http_code 实际值:{self.status_code} == 预期值:{http_code}]')
         return self
     
     def check_code(self, code=0):
@@ -865,19 +865,19 @@ class Message(ABC):
         :param code: response code number
         :return:
         """
-        assert self.code == code, f'[校验失败,response.code 实际值:{self.code} == 预期值：{code}]'
-        logger.info(f'[校验成功,response.code 实际值:{self.code} == 预期值：{code}]')
+        assert self.code == code, f'[校验失败,response.code 实际值:{self.code} == 预期值:{code}]'
+        logger.info(f'[校验成功,response.code 实际值:{self.code} == 预期值:{code}]')
         return self
     
-    def check_values(self, expect_val, actual_val, desc):
+    def check_values(self, expect_val, actual_val, desc=""):
         """
         check response data
         @expect_val : 预期值
         @actual_val : 实际值,取自response data
         @desc : 描述校验信息
         """
-        assert actual_val == expect_val, f'[校验失败,{desc} 实际值:{actual_val} == 预期值：{expect_val}]'
-        logger.info(f'[校验成功,{desc} 实际值:{actual_val} == 预期值：{expect_val}]')
+        assert actual_val == expect_val, f'[校验失败,{desc} 实际值:{actual_val} == 预期值:{expect_val}]'
+        logger.info(f'[校验成功,{desc} 实际值:{actual_val} == 预期值:{expect_val}]')
         return self
 
 
@@ -1039,35 +1039,46 @@ class ServiceStub(ABC):
     """
     session.host = None
     session.common_args = None
+    session.expand_kwargs = None
     
-    def __init__(self, target: str = None, common_args: Dict[str, str] = {}):
+    def __init__(self, target: str = None, common_args: Dict[str, str] = {}, **kwargs):
         if len(common_args) > 0:
-            if session.common_args is None:
-                session.common_args = common_args
-            if session.common_args.get('access_key') != common_args.get('access_key'):
-                session.common_args = common_args
+            session.common_args = common_args
         
         self.suffix_url = "?" + urlencode(session.common_args)
         
-        if session.host is None:
-            session.host = target
-        self._target = session.host
+        if target:
+            self._target = session.host = target
+        else:
+            assert session.host, '[target不能为空,请先初始化或传值]'
+            self._target = session.host
+        # 扩展字段
+        self.kwargs = kwargs
+        if not session.expand_kwargs:
+            session.expand_kwargs = kwargs
     
-    def _do_twirp_rpc(self, api, request: Message, response: Message):
+    def _do_twirp_rpc(self, api, request: Message = Message, response: Message = Message):
         api = api + self.suffix_url
         url = self._target + "/twirp" + api
         logger.info(f'[请求URL]:{url}')
         logger.info(f'[请求数据]:{request.to_json()}')
         r = session.request(
-            method="POST",
-            url=url,
-            data=bytes(request.to_json(), "utf8"),
-            headers={"Content-Type": "application/json"},
-            timeout=60 * 5
+            method="POST" or self.kwargs.get("method"),
+            url=url or self.kwargs.get("url"),
+            data=bytes(request.to_json(), "utf8") or self.kwargs.get("data"),
+            json=self.kwargs.get("json"),
+            headers=session.expand_kwargs.get("headers") or {"Content-Type": "application/json"},
+            timeout=60 * 5,
+            cookies=self.kwargs.get("cookies")
         )
-        logger.info(f'[请求结果]:{r.json()}')
-        logger.info(f'[请求http_code]:{r.status_code}')
-        logger.info(f'[请求耗时]:{r.elapsed.total_seconds()}秒')
+        logger.info(f'[请求cookies]:{r.request.headers._store.get("cookie")}')
+        logger.info(f'[请求headers]:{r.request.headers}')
+        
+        logger.info(f'[响应结果]:{r.json()}')
+        logger.info(f'[响应http_code]:{r.status_code}')
+        logger.info(f'[响应耗时]:{r.elapsed.total_seconds()}秒')
+        logger.info(f'[X-Trace-Id]:{r.request.headers.get("X-Trace-Id")}')
+        # logger.info(f'[响应cookies]:{r.cookies}')
         response.__dict__.update(r.__dict__)
         response.from_json(r.content)
 
